@@ -1,25 +1,9 @@
-/****************************************************************************
-**
-** Copyright (C) 2007 - 2013 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2013 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2021 Rafał Lalik <rafallalik@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "vncview.h"
 #include "krdc_debug.h"
@@ -40,10 +24,10 @@
 #else
     #include "settings.h"
     #include <KActionCollection>
-    #include <KXmlGui/KMainWindow>
-    #include <KWidgetsAddons/KMessageBox>
-    #include <KWidgetsAddons/KPasswordDialog>
-    #include <KXmlGui/KXMLGUIClient>
+    #include <KMainWindow>
+    #include <KMessageBox>
+    #include <KPasswordDialog>
+    #include <KXMLGUIClient>
 #endif
 
 // Definition of key modifier mask constants
@@ -137,8 +121,11 @@ void VncView::scaleResize(int w, int h)
     qCDebug(KRDC) << w << h;
     if (m_scale) {
         const QSize frameSize = m_frame.size() / m_frame.devicePixelRatio();
-        m_verticalFactor = (qreal) h / frameSize.height();
-        m_horizontalFactor = (qreal) w / frameSize.width();
+        const qreal _newW = (frameSize.width() - w) * m_factor + w;
+        const qreal _newH = (frameSize.height() - h) * m_factor + h;
+
+        m_verticalFactor = _newH / frameSize.height();
+        m_horizontalFactor = _newW / frameSize.width();
 
 #ifndef QTONLY
         if (Settings::keepAspectRatio()) {
@@ -208,7 +195,7 @@ void VncView::startQuitting()
     // emit the disconnect siginal only after all the events are handled.
     // Otherwise some error messages might be thrown away without
     // showing to the user.
-    emit disconnected();
+    Q_EMIT disconnected();
     setStatus(Disconnected);
 }
 
@@ -411,7 +398,7 @@ void VncView::outputErrorMessage(const QString &message)
 
     KMessageBox::error(this, message, i18n("VNC failure"));
 
-    emit errorMessage(i18n("VNC failure"), message);
+    Q_EMIT errorMessage(i18n("VNC failure"), message);
 }
 
 void VncView::sshErrorMessage(const QString &message)
@@ -422,7 +409,7 @@ void VncView::sshErrorMessage(const QString &message)
 
     KMessageBox::error(this, message, i18n("SSH Tunnel failure"));
 
-    emit errorMessage(i18n("SSH Tunnel failure"), message);
+    Q_EMIT errorMessage(i18n("SSH Tunnel failure"), message);
 }
 
 #ifndef QTONLY
@@ -451,13 +438,13 @@ void VncView::updateImage(int x, int y, int w, int h)
         setMouseTracking(true); // get mouse events even when there is no mousebutton pressed
         setFocusPolicy(Qt::WheelFocus);
         setStatus(Connected);
-        emit connected();
+        Q_EMIT connected();
 
         if (m_scale) {
 #ifndef QTONLY
             qCDebug(KRDC) << "Setting initial size w:" <<m_hostPreferences->width() << " h:" << m_hostPreferences->height();
             QSize frameSize = QSize(m_hostPreferences->width(), m_hostPreferences->height()) / devicePixelRatioF();
-            emit framebufferSizeChanged(frameSize.width(), frameSize.height());
+            Q_EMIT framebufferSizeChanged(frameSize.width(), frameSize.height());
             scaleResize(frameSize.width(), frameSize.height());
             qCDebug(KRDC) << "m_frame.size():" << m_frame.size() << "size()" << size();
 #else
@@ -491,7 +478,7 @@ void VncView::updateImage(int x, int y, int w, int h)
             resize(frameSize);
             setMaximumSize(frameSize); //This is a hack to force Qt to center the view in the scroll area
             setMinimumSize(frameSize);
-            emit framebufferSizeChanged(frameSize.width(), frameSize.height());
+            Q_EMIT framebufferSizeChanged(frameSize.width(), frameSize.height());
         }
     }
 
